@@ -84,7 +84,6 @@ class Session:
         # server capabilities
         capabilities = client.capabilities()
         has_idle = b"IDLE" in capabilities
-        has_move = b"MOVE" in capabilities
 
         # choose wait mechanism
         wait = self._wait_idle if has_idle else self._wait_poll
@@ -115,8 +114,8 @@ class Session:
                 "parameters": dict(self.parameters) if self.parameters else {}
             }
 
-            logging.info("processing {}/{}/{}".format(
-                self.host, self.mailbox, message))
+            logging.info("processing {}({})/{}/{}".format(
+                self.host, self.port, self.mailbox, message))
             try:
                 exec(self.policy, namespace)
             except Exception as e:
